@@ -92,4 +92,11 @@ void AbstractDocumentImpl::setDocumentErrorString(const QString& string)
     d->mDocument->setErrorString(string);
 }
 
+#ifdef LCMS2_FOUND
+void AbstractDocumentImpl::setDocumentCmsProfile(Cms::Profile::Ptr profile)
+{
+    d->mDocument->setCmsProfile(profile);
+}
+#endif
+
 } // namespace
